# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Ohio."""


ABERDEEN_VILLAGE = "00142"
ADA_VILLAGE = "00198"
ADAMSVILLE_VILLAGE = "00380"
ADDYSTON_VILLAGE = "00436"
ADELPHI_VILLAGE = "00450"
ADENA_VILLAGE = "00464"
AI_CDP = "00541"
AKRON_CITY = "01000"
ALBANY_VILLAGE = "01042"
ALEXANDRIA_VILLAGE = "01154"
ALGER_VILLAGE = "01210"
ALLIANCE_CITY = "01420"
ALVORDTON_CDP = "01588"
AMANDA_VILLAGE = "01630"
AMBERLEY_VILLAGE = "01672"
AMELIA_CDP = "01742"
AMESVILLE_VILLAGE = "01784"
AMHERST_CITY = "01798"
AMSTERDAM_VILLAGE = "01938"
ANDERSONVILLE_CDP = "02022"
ANDOVER_VILLAGE = "02050"
ANNA_VILLAGE = "02092"
ANSONIA_VILLAGE = "02120"
ANTIOCH_VILLAGE = "02148"
ANTWERP_VILLAGE = "02204"
APPLE_CREEK_VILLAGE = "02232"
APPLE_VALLEY_CDP = "02266"
AQUILLA_VILLAGE = "02274"
ARCADIA_VILLAGE = "02316"
ARCANUM_VILLAGE = "02330"
ARCHBOLD_VILLAGE = "02344"
ARLINGTON_HEIGHTS_VILLAGE = "02428"
ARLINGTON_VILLAGE = "02400"
ASHLAND_CITY = "02568"
ASHLEY_VILLAGE = "02582"
ASHTABULA_CITY = "02638"
ASHVILLE_VILLAGE = "02680"
ATHALIA_VILLAGE = "02722"
ATHENS_CITY = "02736"
ATTICA_VILLAGE = "02820"
ATWATER_CDP = "02848"
AURORA_CITY = "03086"
AUSTINBURG_CDP = "03142"
AUSTINTOWN_CDP = "03184"
AVON_LAKE_CITY = "03464"
AVON_CITY = "03352"
BAILEY_LAKES_VILLAGE = "03562"
BAINBRIDGE_CDP = "03585"
BAINBRIDGE_VILLAGE = "03604"
BAIRDSTOWN_VILLAGE = "03646"
BALLVILLE_CDP = "03716"
BALTIC_VILLAGE = "03744"
BALTIMORE_VILLAGE = "03758"
BANNOCK_CDP = "03786"
BARBERTON_CITY = "03828"
BARNESVILLE_VILLAGE = "03926"
BARNHILL_VILLAGE = "03940"
BASCOM_CDP = "04094"
BASS_LAKE_CDP = "04136"
BATAVIA_VILLAGE = "04150"
BATESVILLE_VILLAGE = "04192"
BAY_VIEW_VILLAGE = "04402"
BAY_VILLAGE_CITY = "04416"
BEACH_CITY_VILLAGE = "04458"
BEACHWOOD_CITY = "04500"
BEALLSVILLE_VILLAGE = "04542"
BEAVER_VILLAGE = "04696"
BEAVERCREEK_CITY = "04720"
BEAVERDAM_VILLAGE = "04752"
BECKETT_RIDGE_CDP = "04840"
BEDFORD_HEIGHTS_CITY = "04920"
BEDFORD_CITY = "04878"
BEECHWOOD_TRAILS_CDP = "05013"
BELLAIRE_VILLAGE = "05074"
BELLBROOK_CITY = "05102"
BELLE_CENTER_VILLAGE = "05116"
BELLE_VALLEY_VILLAGE = "05158"
BELLEFONTAINE_CITY = "05130"
BELLEVUE_CITY = "05228"
BELLVILLE_VILLAGE = "05284"
BELMONT_VILLAGE = "05312"
BELMORE_VILLAGE = "05396"
BELOIT_VILLAGE = "05410"
BELPRE_CITY = "05424"
BENTLEYVILLE_VILLAGE = "05550"
BENTON_RIDGE_VILLAGE = "05662"
BENTONVILLE_CDP = "05676"
BEREA_CITY = "05690"
BERGHOLZ_VILLAGE = "05718"
BERKEY_VILLAGE = "05732"
BERLIN_CDP = "05816"
BERLIN_HEIGHTS_VILLAGE = "05900"
BETHEL_VILLAGE = "06068"
BETHESDA_VILLAGE = "06138"
BETTSVILLE_VILLAGE = "06194"
BEULAH_BEACH_CDP = "06208"
BEVERLY_VILLAGE = "06222"
BEXLEY_CITY = "06278"
BIDWELL_CDP = "06320"
BIRMINGHAM_CDP = "06502"
BLACKLICK_ESTATES_CDP = "06670"
BLADENSBURG_CDP = "06740"
BLAINE_CDP = "06754"
BLAKESLEE_VILLAGE = "06810"
BLANCHESTER_VILLAGE = "06908"
BLOOMDALE_VILLAGE = "07062"
BLOOMINGBURG_VILLAGE = "07188"
BLOOMINGDALE_VILLAGE = "07202"
BLOOMINGVILLE_CDP = "07258"
BLOOMVILLE_VILLAGE = "07286"
BLUE_ASH_CITY = "07300"
BLUE_JAY_CDP = "07377"
BLUFFTON_VILLAGE = "07426"
BOLINDALE_CDP = "07583"
BOLIVAR_VILLAGE = "07594"
BOLTON_CDP = "07608"
BOSTON_HEIGHTS_VILLAGE = "07790"
BOTKINS_VILLAGE = "07832"
BOURNEVILLE_CDP = "07888"
BOWERSTON_VILLAGE = "07916"
BOWERSVILLE_VILLAGE = "07930"
BOWLING_GREEN_CITY = "07972"
BRADFORD_VILLAGE = "08084"
BRADNER_VILLAGE = "08112"
BRADY_LAKE_CDP = "08168"
BRANDT_CDP = "08308"
BRATENAHL_VILLAGE = "08336"
BRECKSVILLE_CITY = "08364"
BRECON_CDP = "08378"
BREMEN_VILLAGE = "08392"
BREWSTER_VILLAGE = "08504"
BRICE_VILLAGE = "08532"
BRIDGEPORT_VILLAGE = "08560"
BRIDGETOWN_CDP = "08602"
BRILLIANT_CDP = "08812"
BRIMFIELD_CDP = "08826"
BROADVIEW_HEIGHTS_CITY = "09064"
BROOK_PARK_CITY = "09288"
BROOKFIELD_CENTER_CDP = "09200"
BROOKLYN_HEIGHTS_VILLAGE = "09274"
BROOKLYN_CITY = "09246"
BROOKSIDE_VILLAGE = "09316"
BROOKVILLE_CITY = "09358"
BROUGHTON_VILLAGE = "09386"
BROWNSVILLE_CDP = "09596"
BRUNERSBURG_CDP = "09652"
BRUNSWICK_CITY = "09680"
BRYAN_CITY = "09792"
BUCHTEL_VILLAGE = "09834"
BUCKEYE_LAKE_VILLAGE = "09890"
BUCKLAND_VILLAGE = "09974"
BUCYRUS_CITY = "10030"
BUFFALO_CDP = "10128"
BUFORD_CDP = "10156"
BURBANK_VILLAGE = "10254"
BURGOON_VILLAGE = "10282"
BURKETTSVILLE_VILLAGE = "10296"
BURLINGTON_CDP = "10352"
BURTON_VILLAGE = "10436"
BUTLER_VILLAGE = "10632"
BUTLERVILLE_VILLAGE = "10674"
BYESVILLE_VILLAGE = "10716"
CADIZ_VILLAGE = "10800"
CAIRO_VILLAGE = "10884"
CALCUTTA_CDP = "10926"
CALDWELL_VILLAGE = "10940"
CALEDONIA_VILLAGE = "10954"
CAMBRIDGE_CITY = "10996"
CAMDEN_VILLAGE = "11024"
CAMP_DENNISON_CDP = "11150"
CAMPBELL_CITY = "11066"
CANAL_FULTON_CITY = "11304"
CANAL_LEWISVILLE_CDP = "11318"
CANAL_WINCHESTER_CITY = "11332"
CANDLEWOOD_LAKE_CDP = "11334"
CANFIELD_CITY = "11360"
CANTON_CITY = "12000"
CARBON_HILL_CDP = "12056"
CARDINGTON_VILLAGE = "12084"
CAREY_VILLAGE = "12112"
CARLISLE_VILLAGE = "12168"
CARROLL_VILLAGE = "12252"
CARROLLTON_VILLAGE = "12280"
CASSTOWN_VILLAGE = "12462"
CASTALIA_VILLAGE = "12476"
CASTINE_VILLAGE = "12504"
CATAWBA_VILLAGE = "12560"
CECIL_VILLAGE = "12700"
CEDARVILLE_VILLAGE = "12784"
CELERYVILLE_CDP = "12854"
CELINA_CITY = "12868"
CENTERBURG_VILLAGE = "13036"
CENTERVILLE_THURMAN_VILLAGE = "13169"
CENTERVILLE_CITY = "13190"
CHAGRIN_FALLS_VILLAGE = "13358"
CHAMPION_HEIGHTS_CDP = "13484"
CHARDON_CITY = "13554"
CHATFIELD_VILLAGE = "13694"
CHAUNCEY_VILLAGE = "13778"
CHERRY_FORK_CDP = "13834"
CHERRY_GROVE_CDP = "13848"
CHESAPEAKE_VILLAGE = "13904"
CHESHIRE_VILLAGE = "13932"
CHESTERHILL_VILLAGE = "14086"
CHESTERLAND_CDP = "14100"
CHESTERVILLE_VILLAGE = "14114"
CHEVIOT_CITY = "14128"
CHICKASAW_VILLAGE = "14156"
CHILLICOTHE_CITY = "14184"
CHILO_VILLAGE = "14226"
CHIPPEWA_LAKE_VILLAGE = "14254"
CHIPPEWA_PARK_CDP = "14280"
CHOCTAW_LAKE_CDP = "14288"
CHRISTIANSBURG_VILLAGE = "14296"
CHURCHILL_CDP = "14324"
CINCINNATI_CITY = "15000"
CINNAMON_LAKE_CDP = "15008"
CIRCLEVILLE_CITY = "15070"
CLARINGTON_VILLAGE = "15210"
CLARKSBURG_VILLAGE = "15336"
CLARKSVILLE_VILLAGE = "15406"
CLARKTOWN_CDP = "15434"
CLAY_CENTER_VILLAGE = "15588"
CLAYTON_CITY = "15644"
CLEVELAND_HEIGHTS_CITY = "16014"
CLEVELAND_CITY = "16000"
CLEVES_VILLAGE = "16028"
CLIFTON_VILLAGE = "16056"
CLINTON_VILLAGE = "16182"
CLOVERDALE_VILLAGE = "16266"
CLYDE_CITY = "16308"
COAL_GROVE_VILLAGE = "16378"
COALTON_VILLAGE = "16434"
COLDSTREAM_CDP = "16521"
COLDWATER_VILLAGE = "16532"
COLLEGE_CORNER_VILLAGE = "16700"
COLLINS_CDP = "16784"
COLUMBIANA_CITY = "17036"
COLUMBUS_GROVE_VILLAGE = "18014"
COLUMBUS_CITY = "18000"
COMMERCIAL_POINT_VILLAGE = "18070"
CONCORDE_HILLS_CDP = "18244"
CONESVILLE_VILLAGE = "18266"
CONGRESS_VILLAGE = "18308"
CONNEAUT_CITY = "18350"
CONNORVILLE_CDP = "18420"
CONTINENTAL_VILLAGE = "18504"
CONVOY_VILLAGE = "18546"
COOLVILLE_VILLAGE = "18588"
CORNING_VILLAGE = "18770"
CORTLAND_CITY = "18812"
CORWIN_VILLAGE = "18840"
COSHOCTON_CITY = "18868"
COVEDALE_CDP = "19008"
COVINGTON_VILLAGE = "19050"
CRAIG_BEACH_VILLAGE = "19106"
CRESTLINE_VILLAGE = "19330"
CRESTON_VILLAGE = "19344"
CRIDERSVILLE_VILLAGE = "19400"
CROOKSVILLE_VILLAGE = "19456"
CROWN_CITY_VILLAGE = "19554"
CRYSTAL_LAKES_CDP = "19596"
CRYSTAL_ROCK_CDP = "19615"
CUMBERLAND_VILLAGE = "19694"
CURTICE_CDP = "19736"
CUSTAR_VILLAGE = "19750"
CUYAHOGA_FALLS_CITY = "19778"
CUYAHOGA_HEIGHTS_VILLAGE = "19806"
CYGNET_VILLAGE = "19820"
CYNTHIANA_CDP = "19848"
DALTON_VILLAGE = "19974"
DAMASCUS_CDP = "20030"
DANVILLE_VILLAGE = "20114"
DARBYDALE_CDP = "20198"
DARBYVILLE_VILLAGE = "20212"
DARRTOWN_CDP = "20268"
DAY_HEIGHTS_CDP = "20366"
DAYTON_CITY = "21000"
DE_GRAFF_VILLAGE = "21378"
DEER_PARK_CITY = "21266"
DEERSVILLE_VILLAGE = "21294"
DEFIANCE_CITY = "21308"
DELAWARE_CITY = "21434"
DELHI_HILLS_CDP = "21518"
DELLROY_VILLAGE = "21560"
DELPHOS_CITY = "21602"
DELSHIRE_CDP = "21610"
DELTA_VILLAGE = "21616"
DENNISON_VILLAGE = "21714"
DENT_CDP = "21742"
DERBY_CDP = "21784"
DESHLER_VILLAGE = "21812"
DEVOLA_CDP = "21868"
DEXTER_CITY_VILLAGE = "21910"
DILLONVALE_CDP = "22008"
DILLONVALE_VILLAGE = "22022"
DOLA_CDP = "22260"
DONNELSVILLE_VILLAGE = "22288"
DOVER_CITY = "22456"
DOYLESTOWN_VILLAGE = "22568"
DRESDEN_VILLAGE = "22610"
DREXEL_CDP = "22624"
DRY_RIDGE_CDP = "22660"
DRY_RUN_CDP = "22674"
DUBLIN_CITY = "22694"
DUNCAN_FALLS_CDP = "22820"
DUNDEE_CDP = "22848"
DUNKIRK_VILLAGE = "22946"
DUNLAP_CDP = "22960"
DUPONT_VILLAGE = "22974"
EAST_ALLIANCE_CDP = "23254"
EAST_CANTON_VILLAGE = "23324"
EAST_CLEVELAND_CITY = "23380"
EAST_FULTONHAM_CDP = "23534"
EAST_LIBERTY_CDP = "23702"
EAST_LIVERPOOL_CITY = "23730"
EAST_PALESTINE_VILLAGE = "23940"
EAST_ROCHESTER_CDP = "24024"
EAST_SPARTA_VILLAGE = "24052"
EAST_SPRINGFIELD_CDP = "24066"
EASTLAKE_CITY = "23618"
EATON_ESTATES_CDP = "24262"
EATON_CITY = "24234"
EDGERTON_VILLAGE = "24486"
EDGEWOOD_CDP = "24542"
EDISON_VILLAGE = "24598"
EDON_VILLAGE = "24640"
ELDORADO_VILLAGE = "24766"
ELGIN_VILLAGE = "24794"
ELIDA_VILLAGE = "24808"
ELIZABETHTOWN_CDP = "24850"
ELMORE_VILLAGE = "25144"
ELMWOOD_PLACE_VILLAGE = "25186"
ELYRIA_CITY = "25256"
EMPIRE_VILLAGE = "25368"
ENGLEWOOD_CITY = "25396"
ENON_VILLAGE = "25452"
ETNA_CDP = "25676"
EUCLID_CITY = "25704"
EVENDALE_VILLAGE = "25802"
FAIRBORN_CITY = "25914"
FAIRFAX_VILLAGE = "25942"
FAIRFIELD_BEACH_CDP = "26110"
FAIRFIELD_CITY = "25970"
FAIRLAWN_CITY = "26166"
FAIRPORT_HARBOR_VILLAGE = "26306"
FAIRVIEW_PARK_CITY = "26446"
FAIRVIEW_VILLAGE = "26348"
FARMERSVILLE_VILLAGE = "26656"
FAYETTE_VILLAGE = "26768"
FAYETTEVILLE_VILLAGE = "26796"
FELICITY_VILLAGE = "26880"
FINDLAY_CITY = "27048"
FINNEYTOWN_CDP = "27104"
FIVE_POINTS_CDP = "27303"
FLAT_ROCK_CDP = "27356"
FLETCHER_VILLAGE = "27412"
FLORIDA_VILLAGE = "27538"
FLUSHING_VILLAGE = "27552"
FOREST_PARK_CITY = "27706"
FOREST_VILLAGE = "27636"
FORESTVILLE_CDP = "27776"
FORT_JENNINGS_VILLAGE = "27818"
FORT_LORAMIE_VILLAGE = "27832"
FORT_MCKINLEY_CDP = "27846"
FORT_RECOVERY_VILLAGE = "27902"
FORT_SENECA_CDP = "27930"
FORT_SHAWNEE_CDP = "27944"
FOSTORIA_CITY = "28014"
FOUR_BRIDGES_CDP = "28058"
FRANKFORT_VILLAGE = "28182"
FRANKLIN_FURNACE_CDP = "28532"
FRANKLIN_CITY = "28476"
FRAZEYSBURG_VILLAGE = "28574"
FREDERICKSBURG_VILLAGE = "28616"
FREDERICKTOWN_VILLAGE = "28658"
FREEPORT_VILLAGE = "28798"
FREMONT_CITY = "28826"
FRESNO_CDP = "28882"
FRIENDSHIP_CDP = "28896"
FRUIT_HILL_CDP = "28966"
FULTON_VILLAGE = "29050"
FULTONHAM_VILLAGE = "29064"
GAHANNA_CITY = "29106"
GALENA_VILLAGE = "29148"
GALION_CITY = "29162"
GALLIPOLIS_VILLAGE = "29204"
GAMBIER_VILLAGE = "29246"
GANN_BRINKHAVEN_VILLAGE = "29288"
GARFIELD_HEIGHTS_CITY = "29428"
GARRETTSVILLE_VILLAGE = "29442"
GATES_MILLS_VILLAGE = "29498"
GENEVA_CITY = "29610"
GENEVA_ON_THE_LAKE_VILLAGE = "29652"
GENOA_VILLAGE = "29722"
GEORGETOWN_VILLAGE = "29778"
GERMANTOWN_CITY = "29932"
GETTYSBURG_VILLAGE = "29974"
GIBSONBURG_VILLAGE = "30072"
GILBOA_VILLAGE = "30114"
GIRARD_CITY = "30198"
GLANDORF_VILLAGE = "30282"
GLENCOE_CDP = "30352"
GLENDALE_VILLAGE = "30380"
GLENFORD_VILLAGE = "30436"
GLENMONT_VILLAGE = "30506"
GLENMOOR_CDP = "30520"
GLENWILLOW_VILLAGE = "30632"
GLORIA_GLENS_PARK_VILLAGE = "30660"
GLOUSTER_VILLAGE = "30674"
GNADENHUTTEN_VILLAGE = "30702"
GOLF_MANOR_VILLAGE = "30786"
GOMER_CDP = "30814"
GOOD_HOPE_CDP = "30828"
GORDON_VILLAGE = "30912"
GOSHEN_CDP = "30996"
GRAFTON_VILLAGE = "31150"
GRAND_RAPIDS_VILLAGE = "31206"
GRAND_RIVER_VILLAGE = "31234"
GRANDVIEW_CDP = "31262"
GRANDVIEW_HEIGHTS_CITY = "31304"
GRANVILLE_SOUTH_CDP = "31434"
GRANVILLE_VILLAGE = "31402"
GRATIOT_VILLAGE = "31458"
GRATIS_VILLAGE = "31472"
GRAYSVILLE_VILLAGE = "31542"
GREEN_CAMP_VILLAGE = "31948"
GREEN_MEADOWS_CDP = "32207"
GREEN_SPRINGS_VILLAGE = "32256"
GREEN_CITY = "31860"
GREENFIELD_VILLAGE = "32088"
GREENHILLS_VILLAGE = "32158"
GREENTOWN_CDP = "32298"
GREENVILLE_CITY = "32340"
GREENWICH_VILLAGE = "32368"
GROESBECK_CDP = "32536"
GROVE_CITY_CITY = "32592"
GROVEPORT_CITY = "32606"
GROVER_HILL_VILLAGE = "32620"
GUILFORD_LAKE_CDP = "32680"
HAMBURG_CDP = "32928"
HAMDEN_VILLAGE = "32956"
HAMERSVILLE_VILLAGE = "32984"
HAMILTON_CITY = "33012"
HAMLER_VILLAGE = "33096"
HANGING_ROCK_VILLAGE = "33194"
HANNIBAL_CDP = "33222"
HANOVER_VILLAGE = "33292"
HANOVERTON_VILLAGE = "33306"
HARBOR_HILLS_CDP = "33362"
HARBOR_VIEW_VILLAGE = "33376"
HARPSTER_VILLAGE = "33656"
HARRISBURG_CDP = "33768"
HARRISBURG_VILLAGE = "33740"
HARRISON_CITY = "33838"
HARRISVILLE_VILLAGE = "34090"
HARROD_VILLAGE = "34118"
HARTFORD_CROTON_VILLAGE = "34202"
HARTVILLE_VILLAGE = "34328"
HARVEYSBURG_VILLAGE = "34384"
HASKINS_VILLAGE = "34412"
HAVILAND_VILLAGE = "34552"
HAYDENVILLE_CDP = "34594"
HAYESVILLE_VILLAGE = "34636"
HEATH_CITY = "34748"
HEBRON_VILLAGE = "34790"
HELENA_VILLAGE = "34860"
HEMLOCK_VILLAGE = "34888"
HESSVILLE_CDP = "35028"
HICKSVILLE_VILLAGE = "35098"
HIDDEN_LAKES_CDP = "35119"
HIDE_A_WAY_HILLS_CDP = "35126"
HIGGINSPORT_VILLAGE = "35168"
HIGHLAND_HEIGHTS_CITY = "35252"
HIGHLAND_HILLS_VILLAGE = "35255"
HIGHLAND_HOLIDAY_CDP = "35256"
HIGHLAND_VILLAGE = "35210"
HIGHPOINT_CDP = "35322"
HILLIARD_CITY = "35476"
HILLS_AND_DALES_VILLAGE = "35532"
HILLSBORO_CITY = "35560"
HILLTOP_CDP = "35613"
HIRAM_VILLAGE = "35658"
HOCKINGPORT_CDP = "35826"
HOLGATE_VILLAGE = "35854"
HOLIDAY_CITY_VILLAGE = "35864"
HOLIDAY_LAKES_CDP = "35866"
HOLIDAY_VALLEY_CDP = "35868"
HOLLAND_VILLAGE = "35882"
HOLLANSBURG_VILLAGE = "35896"
HOLLOWAY_VILLAGE = "35924"
HOLMESVILLE_VILLAGE = "35994"
HOMEWORTH_CDP = "36176"
HOOVEN_CDP = "36232"
HOPEDALE_VILLAGE = "36260"
HOWARD_CDP = "36512"
HOWLAND_CENTER_CDP = "36557"
HOYTVILLE_VILLAGE = "36568"
HUBBARD_CITY = "36582"
HUBER_HEIGHTS_CITY = "36610"
HUBER_RIDGE_CDP = "36624"
HUDSON_CITY = "36651"
HUNTER_CDP = "36806"
HUNTING_VALLEY_VILLAGE = "36918"
HUNTSVILLE_VILLAGE = "36988"
HURON_CITY = "37016"
IBERIA_CDP = "37142"
INDEPENDENCE_CITY = "37240"
IRONDALE_VILLAGE = "37422"
IRONTON_CITY = "37464"
ITHACA_VILLAGE = "37604"
JACKSON_CENTER_VILLAGE = "38220"
JACKSON_CITY = "37842"
JACKSONBURG_VILLAGE = "38192"
JACKSONTOWN_CDP = "38276"
JACKSONVILLE_VILLAGE = "38304"
JAMESTOWN_VILLAGE = "38374"
JEFFERSON_VILLAGE = "38500"
JEFFERSONVILLE_VILLAGE = "38920"
JENERA_VILLAGE = "38948"
JEROMESVILLE_VILLAGE = "39060"
JERRY_CITY_VILLAGE = "39074"
JERSEY_CDP = "39088"
JERUSALEM_VILLAGE = "39130"
JEWETT_VILLAGE = "39172"
JOHNSTOWN_VILLAGE = "39340"
JUNCTION_CITY_VILLAGE = "39508"
KALIDA_VILLAGE = "39536"
KANAUGA_CDP = "39564"
KANSAS_CDP = "39578"
KELLEYS_ISLAND_VILLAGE = "39662"
KENT_CITY = "39872"
KENTON_CITY = "39886"
KENWOOD_CDP = "39914"
KETTERING_CITY = "40040"
KETTLERSVILLE_VILLAGE = "40054"
KIDRON_CDP = "40096"
KILBOURNE_CDP = "40124"
KILLBUCK_VILLAGE = "40180"
KIMBOLTON_CDP = "40264"
KINGS_MILLS_CDP = "40348"
KINGSTON_VILLAGE = "40376"
KINGSVILLE_CDP = "40390"
KINSMAN_CENTER_CDP = "40507"
KIPTON_VILLAGE = "40544"
KIRBY_VILLAGE = "40558"
KIRKERSVILLE_VILLAGE = "40572"
KIRTLAND_HILLS_VILLAGE = "40670"
KIRTLAND_CITY = "40642"
KUNKLE_CDP = "40978"
LA_CROFT_CDP = "41090"
LA_RUE_VILLAGE = "41902"
LAGRANGE_VILLAGE = "41230"
LAFAYETTE_CDP = "41146"
LAFAYETTE_VILLAGE = "41118"
LAFFERTY_CDP = "41188"
LAKE_BUCKHORN_CDP = "41349"
LAKE_DARBY_CDP = "41363"
LAKE_LAKENGREN_CDP = "41373"
LAKE_LORELEI_CDP = "41419"
LAKE_MILTON_CDP = "41440"
LAKE_MOHAWK_CDP = "41443"
LAKE_SENECA_CDP = "41500"
LAKE_TOMAHAWK_CDP = "41597"
LAKE_WAYNOKA_CDP = "41657"
LAKELINE_VILLAGE = "41398"
LAKEMORE_VILLAGE = "41454"
LAKESIDE_CDP = "41552"
LAKEVIEW_VILLAGE = "41608"
LAKEWOOD_CITY = "41664"
LANCASTER_CITY = "41720"
LANDEN_CDP = "41755"
LANSING_CDP = "41860"
LATTY_VILLAGE = "41986"
LAURA_VILLAGE = "42028"
LAURELVILLE_VILLAGE = "42084"
LAWRENCEVILLE_CDP = "42210"
LEAVITTSBURG_CDP = "42308"
LEBANON_CITY = "42364"
LEESBURG_VILLAGE = "42476"
LEESVILLE_VILLAGE = "42518"
LEETONIA_VILLAGE = "42560"
LEIPSIC_VILLAGE = "42602"
LEWISBURG_VILLAGE = "42938"
LEWISTOWN_CDP = "42966"
LEWISVILLE_VILLAGE = "42980"
LEXINGTON_VILLAGE = "42994"
LIBERTY_CENTER_VILLAGE = "43414"
LIMA_CITY = "43554"
LIMAVILLE_CDP = "43596"
LINCOLN_HEIGHTS_CDP = "43764"
LINCOLN_HEIGHTS_VILLAGE = "43722"
LINCOLN_VILLAGE_CDP = "43792"
LINDSEY_VILLAGE = "43904"
LINNDALE_VILLAGE = "43918"
LISBON_VILLAGE = "44030"
LITHOPOLIS_VILLAGE = "44086"
LITTLE_HOCKING_CDP = "44128"
LLOYDSVILLE_CDP = "44282"
LOCKBOURNE_VILLAGE = "44310"
LOCKINGTON_VILLAGE = "44352"
LOCKLAND_VILLAGE = "44366"
LODI_VILLAGE = "44604"
LOGAN_ELM_VILLAGE_CDP = "44636"
LOGAN_CITY = "44632"
LONDON_CITY = "44674"
LORAIN_CITY = "44856"
LORDSTOWN_VILLAGE = "44912"
LORE_CITY_VILLAGE = "44954"
LOUDONVILLE_VILLAGE = "45066"
LOUISVILLE_CITY = "45094"
LOVELAND_PARK_CDP = "45122"
LOVELAND_CITY = "45108"
LOWELL_VILLAGE = "45164"
LOWELLVILLE_VILLAGE = "45178"
LOWER_SALEM_VILLAGE = "45220"
LUCAS_VILLAGE = "45276"
LUCASVILLE_CDP = "45304"
LUCKEY_VILLAGE = "45332"
LUDLOW_FALLS_VILLAGE = "45374"
LYNCHBURG_VILLAGE = "45542"
LYNDHURST_CITY = "45556"
LYONS_VILLAGE = "45626"
MACEDONIA_CITY = "45976"
MACK_CDP = "46088"
MACKSBURG_VILLAGE = "46158"
MADEIRA_CITY = "46312"
MADISON_PLACE_CDP = "46736"
MADISON_VILLAGE = "46480"
MAGNETIC_SPRINGS_VILLAGE = "46830"
MAGNOLIA_VILLAGE = "46844"
MAINEVILLE_VILLAGE = "46872"
MALINTA_VILLAGE = "46942"
MALTA_VILLAGE = "46970"
MALVERN_VILLAGE = "46998"
MANCHESTER_VILLAGE = "47012"
MANSFIELD_CITY = "47138"
MANTUA_VILLAGE = "47180"
MAPLE_HEIGHTS_CITY = "47306"
MAPLE_RIDGE_CDP = "47362"
MAPLEWOOD_PARK_CDP = "47445"
MARATHON_CDP = "47460"
MARBLE_CLIFF_VILLAGE = "47474"
MARBLEHEAD_VILLAGE = "47502"
MARENGO_VILLAGE = "47558"
MARIA_STEIN_CDP = "47586"
MARIEMONT_VILLAGE = "47600"
MARIETTA_CITY = "47628"
MARION_CITY = "47754"
MARLBORO_CDP = "47922"
MARNE_CDP = "47950"
MARSEILLES_VILLAGE = "47992"
MARSHALLVILLE_VILLAGE = "48048"
MARTINS_FERRY_CITY = "48104"
MARTINSBURG_VILLAGE = "48090"
MARTINSVILLE_VILLAGE = "48118"
MARYSVILLE_CITY = "48160"
MASON_CITY = "48188"
MASSIEVILLE_CDP = "48230"
MASSILLON_CITY = "48244"
MASURY_CDP = "48272"
MATAMORAS_VILLAGE = "48286"
MAUMEE_CITY = "48342"
MAYFIELD_HEIGHTS_CITY = "48482"
MAYFIELD_VILLAGE = "48468"
MCARTHUR_VILLAGE = "45696"
MCCLURE_VILLAGE = "45794"
MCCOMB_VILLAGE = "45808"
MCCONNELSVILLE_VILLAGE = "45822"
MCCUTCHENVILLE_CDP = "45892"
MCDERMOTT_CDP = "45906"
MCDONALD_VILLAGE = "45934"
MCGUFFEY_VILLAGE = "46046"
MCKINLEY_HEIGHTS_CDP = "46144"
MECHANICSBURG_VILLAGE = "48706"
MEDINA_CITY = "48790"
MEDWAY_CDP = "48832"
MELMORE_CDP = "48972"
MELROSE_VILLAGE = "49000"
MENDON_VILLAGE = "49042"
MENTOR_CITY = "49056"
MENTOR_ON_THE_LAKE_CITY = "49098"
METAMORA_VILLAGE = "49238"
MEYERS_LAKE_VILLAGE = "49294"
MIAMI_HEIGHTS_CDP = "49420"
MIAMISBURG_CITY = "49434"
MIAMITOWN_CDP = "49462"
MIAMIVILLE_CDP = "49504"
MIDDLE_POINT_VILLAGE = "49728"
MIDDLEBRANCH_CDP = "49588"
MIDDLEBURG_HEIGHTS_CITY = "49644"
MIDDLEFIELD_VILLAGE = "49700"
MIDDLEPORT_VILLAGE = "49756"
MIDDLETOWN_CITY = "49840"
MIDLAND_VILLAGE = "49896"
MIDVALE_VILLAGE = "49966"
MIDWAY_VILLAGE = "50008"
MIFFLIN_VILLAGE = "50036"
MILAN_VILLAGE = "50134"
MILFORD_CENTER_VILLAGE = "50218"
MILFORD_CITY = "50176"
MILLBURY_VILLAGE = "50260"
MILLEDGEVILLE_VILLAGE = "50316"
MILLER_CDP = "50344"
MILLER_CITY_VILLAGE = "50358"
MILLERSBURG_VILLAGE = "50372"
MILLERSPORT_VILLAGE = "50400"
MILLFIELD_CDP = "50456"
MILLVILLE_VILLAGE = "50540"
MILTON_CENTER_VILLAGE = "50708"
MILTONSBURG_VILLAGE = "50722"
MINERAL_CITY_VILLAGE = "50764"
MINERAL_RIDGE_CDP = "50778"
MINERVA_PARK_VILLAGE = "50862"
MINERVA_VILLAGE = "50834"
MINFORD_CDP = "50876"
MINGO_JUNCTION_VILLAGE = "50904"
MINSTER_VILLAGE = "50918"
MITIWANGA_CDP = "50974"
MOGADORE_VILLAGE = "51058"
MONFORT_HEIGHTS_CDP = "51212"
MONROE_CITY = "51310"
MONROEVILLE_VILLAGE = "51618"
MONTEZUMA_VILLAGE = "51674"
MONTGOMERY_CITY = "51716"
MONTPELIER_VILLAGE = "51772"
MONTROSE_GHENT_CDP = "51816"
MORAINE_CITY = "52010"
MORELAND_HILLS_VILLAGE = "52052"
MORGANDALE_CDP = "52178"
MORRAL_VILLAGE = "52276"
MORRISTOWN_VILLAGE = "52346"
MORROW_VILLAGE = "52374"
MOSCOW_VILLAGE = "52416"
MOUNT_BLANCHARD_VILLAGE = "52598"
MOUNT_CARMEL_CDP = "52612"
MOUNT_CORY_VILLAGE = "52668"
MOUNT_EATON_VILLAGE = "52682"
MOUNT_GILEAD_VILLAGE = "52738"
MOUNT_HEALTHY_HEIGHTS_CDP = "52780"
MOUNT_HEALTHY_CITY = "52752"
MOUNT_HOPE_CDP = "52822"
MOUNT_ORAB_VILLAGE = "52906"
MOUNT_PLEASANT_VILLAGE = "52976"
MOUNT_REPOSE_CDP = "53032"
MOUNT_STERLING_VILLAGE = "53046"
MOUNT_VERNON_CITY = "53102"
MOUNT_VICTORY_VILLAGE = "53144"
MOWRYSTOWN_VILLAGE = "53186"
MULBERRY_CDP = "53270"
MUNROE_FALLS_CITY = "53312"
MURRAY_CITY_VILLAGE = "53410"
MUTUAL_VILLAGE = "53480"
NANKIN_CDP = "53536"
NAPOLEON_CITY = "53550"
NASHPORT_CDP = "53606"
NASHVILLE_VILLAGE = "53634"
NAVARRE_VILLAGE = "53690"
NEAPOLIS_CDP = "53718"
NEFFS_CDP = "53788"
NEGLEY_CDP = "53802"
NELLIE_VILLAGE = "53816"
NELSONVILLE_CITY = "53886"
NETTLE_LAKE_CDP = "53914"
NEVADA_VILLAGE = "53942"
NEVILLE_VILLAGE = "53956"
NEW_ALBANY_CITY = "53970"
NEW_ALEXANDRIA_VILLAGE = "54012"
NEW_ATHENS_VILLAGE = "54068"
NEW_BALTIMORE_CDP = "54082"
NEW_BAVARIA_VILLAGE = "54110"
NEW_BLOOMINGTON_VILLAGE = "54152"
NEW_BOSTON_VILLAGE = "54166"
NEW_BREMEN_VILLAGE = "54194"
NEW_BURLINGTON_CDP = "54264"
NEW_CALIFORNIA_CDP = "54320"
NEW_CARLISLE_CITY = "54334"
NEW_CONCORD_VILLAGE = "54446"
NEW_FRANKLIN_CITY = "54562"
NEW_HAMPSHIRE_CDP = "54628"
NEW_HAVEN_CDP_HAMILTON_COUNTY = "54684"
NEW_HAVEN_CDP_HURON_COUNTY = "54698"
NEW_HOLLAND_VILLAGE = "54726"
NEW_KNOXVILLE_VILLAGE = "54838"
NEW_LEBANON_VILLAGE = "54852"
NEW_LEXINGTON_VILLAGE = "54866"
NEW_LONDON_VILLAGE = "54908"
NEW_MADISON_VILLAGE = "54978"
NEW_MARSHFIELD_CDP = "55062"
NEW_MIAMI_VILLAGE = "55104"
NEW_MIDDLETOWN_VILLAGE = "55118"
NEW_PARIS_VILLAGE = "55188"
NEW_PHILADELPHIA_CITY = "55216"
NEW_PITTSBURG_CDP = "55244"
NEW_RICHMOND_VILLAGE = "55384"
NEW_RIEGEL_VILLAGE = "55398"
NEW_SPRINGFIELD_CDP = "55524"
NEW_STRAITSVILLE_VILLAGE = "55552"
NEW_VIENNA_VILLAGE = "55748"
NEW_WASHINGTON_VILLAGE = "55776"
NEW_WATERFORD_VILLAGE = "55790"
NEW_WESTON_VILLAGE = "55818"
NEWARK_CITY = "54040"
NEWBURGH_HEIGHTS_VILLAGE = "54250"
NEWCOMERSTOWN_VILLAGE = "54432"
NEWPORT_CDP_SHELBY_COUNTY = "55314"
NEWPORT_CDP_WASHINGTON_COUNTY = "55342"
NEWTON_FALLS_VILLAGE = "55650"
NEWTOWN_VILLAGE = "55678"
NEY_VILLAGE = "55874"
NILES_CITY = "55916"
NORTH_BALTIMORE_VILLAGE = "56154"
NORTH_BEND_VILLAGE = "56182"
NORTH_CANTON_CITY = "56294"
NORTH_COLLEGE_HILL_CITY = "56322"
NORTH_FAIRFIELD_VILLAGE = "56420"
NORTH_HAMPTON_VILLAGE = "56588"
NORTH_INDUSTRY_CDP = "56658"
NORTH_KINGSVILLE_VILLAGE = "56700"
NORTH_LAWRENCE_CDP = "56756"
NORTH_LEWISBURG_VILLAGE = "56770"
NORTH_LIMA_CDP = "56798"
NORTH_MADISON_CDP = "56812"
NORTH_OLMSTED_CITY = "56882"
NORTH_PERRY_VILLAGE = "56910"
NORTH_RANDALL_VILLAGE = "56924"
NORTH_RIDGEVILLE_CITY = "56966"
NORTH_ROBINSON_VILLAGE = "56994"
NORTH_ROYALTON_CITY = "57008"
NORTH_STAR_VILLAGE = "57064"
NORTH_ZANESVILLE_CDP = "57218"
NORTHBROOK_CDP = "56280"
NORTHFIELD_VILLAGE = "56448"
NORTHGATE_CDP = "56553"
NORTHRIDGE_CDP = "56938"
NORTHWOOD_CITY = "57190"
NORTON_CITY = "57260"
NORWALK_CITY = "57302"
NORWICH_VILLAGE = "57372"
NORWOOD_CITY = "57386"
OAK_HARBOR_VILLAGE = "57582"
OAK_HILL_VILLAGE = "57596"
OAKWOOD_CITY = "57764"
OAKWOOD_VILLAGE_CUYAHOGA_COUNTY = "57750"
OAKWOOD_VILLAGE_PAULDING_COUNTY = "57792"
OBERLIN_CITY = "57834"
OBETZ_VILLAGE = "57862"
OCEOLA_CDP = "57876"
OCTA_VILLAGE = "57918"
OHIO_CITY_VILLAGE = "58002"
OLD_FORT_CDP = "58156"
OLD_WASHINGTON_VILLAGE = "58226"
OLDE_WEST_CHESTER_CDP = "58149"
OLMSTED_FALLS_CITY = "58422"
ONTARIO_CITY = "58520"
ORANGE_VILLAGE = "58604"
ORANGEVILLE_VILLAGE = "58674"
OREGON_CITY = "58730"
ORIENT_CDP = "58800"
ORRVILLE_CITY = "58828"
ORWELL_VILLAGE = "58856"
OSGOOD_VILLAGE = "58912"
OSTRANDER_VILLAGE = "58940"
OTTAWA_HILLS_VILLAGE = "59010"
OTTAWA_VILLAGE = "58982"
OTTOVILLE_VILLAGE = "59052"
OTWAY_VILLAGE = "59066"
OWENSVILLE_VILLAGE = "59220"
OXFORD_CITY = "59234"
PAINESVILLE_CITY = "59416"
PALESTINE_VILLAGE = "59598"
PANCOASTBURG_CDP = "59724"
PANDORA_VILLAGE = "59738"
PARK_LAYNE_CDP = "59920"
PARKMAN_CDP = "59934"
PARMA_HEIGHTS_CITY = "61028"
PARMA_CITY = "61000"
PARRAL_VILLAGE = "61056"
PATASKALA_CITY = "61112"
PATTERSON_VILLAGE = "61182"
PAULDING_VILLAGE = "61252"
PAYNE_VILLAGE = "61322"
PEEBLES_VILLAGE = "61420"
PEKIN_CDP = "61448"
PEMBERVILLE_VILLAGE = "61504"
PENINSULA_VILLAGE = "61574"
PEPPER_PIKE_CITY = "61686"
PERRY_HEIGHTS_CDP = "62134"
PERRY_VILLAGE = "61882"
PERRYSBURG_CITY = "62148"
PERRYSVILLE_VILLAGE = "62190"
PETERSBURG_CDP = "62302"
PETTISVILLE_CDP = "62344"
PHEASANT_RUN_CDP = "62404"
PHILLIPSBURG_VILLAGE = "62414"
PHILO_VILLAGE = "62442"
PICKERINGTON_CITY = "62498"
PIGEON_CREEK_CDP = "62578"
PIKETON_VILLAGE = "62708"
PIONEER_VILLAGE = "62834"
PIQUA_CITY = "62848"
PITSBURG_VILLAGE = "62890"
PLAIN_CITY_VILLAGE = "63030"
PLAINFIELD_VILLAGE = "63044"
PLAINVILLE_CDP = "63072"
PLEASANT_CITY_VILLAGE = "63436"
PLEASANT_GROVE_CDP = "63478"
PLEASANT_HILL_VILLAGE = "63534"
PLEASANT_HILLS_CDP = "63548"
PLEASANT_PLAIN_VILLAGE = "63576"
PLEASANT_RUN_CDP = "63604"
PLEASANT_RUN_FARM_CDP = "63618"
PLEASANTVILLE_VILLAGE = "63716"
PLUMWOOD_CDP = "63758"
PLYMOUTH_VILLAGE = "63800"
POLAND_VILLAGE = "63954"
POLK_VILLAGE = "63996"
POMEROY_VILLAGE = "64024"
PORT_CLINTON_CITY = "64150"
PORT_JEFFERSON_VILLAGE = "64262"
PORT_WASHINGTON_VILLAGE = "64346"
PORT_WILLIAM_VILLAGE = "64360"
PORTAGE_LAKES_CDP = "64136"
PORTAGE_VILLAGE = "64108"
PORTSMOUTH_CITY = "64304"
POTSDAM_VILLAGE = "64430"
POTTERY_ADDITION_CDP = "64472"
POWELL_CITY = "64486"
POWHATAN_POINT_VILLAGE = "64542"
PROCTORVILLE_VILLAGE = "64766"
PROSPECT_VILLAGE = "64780"
PULASKI_CDP = "64906"
PUT_IN_BAY_VILLAGE = "65032"
QUAKER_CITY_VILLAGE = "65116"
QUINCY_VILLAGE = "65200"
RACINE_VILLAGE = "65256"
RADNOR_CDP = "65298"
RARDEN_VILLAGE = "65508"
RAVENNA_CITY = "65592"
RAWSON_VILLAGE = "65634"
RAYLAND_VILLAGE = "65662"
RAYMOND_CDP = "65676"
READING_CITY = "65732"
REEDURBAN_CDP = "66012"
REMINDERVILLE_VILLAGE = "66152"
REMINGTON_CDP = "66180"
RENDVILLE_VILLAGE = "66222"
RENO_BEACH_CDP = "66264"
RENO_CDP = "66250"
REPUBLIC_VILLAGE = "66320"
REYNOLDSBURG_CITY = "66390"
RICHFIELD_VILLAGE = "66530"
RICHMOND_DALE_CDP = "66880"
RICHMOND_HEIGHTS_CITY = "66894"
RICHMOND_VILLAGE = "66824"
RICHVILLE_CDP = "66922"
RICHWOOD_VILLAGE = "66936"
RIDGEVILLE_CORNERS_CDP = "67104"
RIDGEWAY_VILLAGE = "67118"
RIDGEWOOD_CDP = "67128"
RIO_GRANDE_VILLAGE = "67258"
RIPLEY_VILLAGE = "67272"
RISINGSUN_VILLAGE = "67314"
RITTMAN_CITY = "67356"
RIVERLEA_VILLAGE = "67440"
RIVERSIDE_CITY = "67468"
ROACHESTER_CDP = "67580"
ROAMING_SHORES_VILLAGE = "67600"
ROBERTSVILLE_CDP = "67664"
ROCHESTER_VILLAGE = "67762"
ROCK_CREEK_VILLAGE = "67846"
ROCKBRIDGE_CDP = "67804"
ROCKFORD_VILLAGE = "67874"
ROCKY_FORK_POINT_CDP = "68004"
ROCKY_RIDGE_VILLAGE = "68042"
ROCKY_RIVER_CITY = "68056"
ROGERS_VILLAGE = "68084"
ROME_STOUT_VILLAGE = "68196"
ROSE_FARM_CDP = "68448"
ROSELAND_CDP = "68490"
ROSEMOUNT_CDP = "68546"
ROSEVILLE_VILLAGE = "68560"
ROSEWOOD_CDP = "68574"
ROSS_CDP = "68602"
ROSSBURG_VILLAGE = "68672"
ROSSFORD_CITY = "68686"
ROSSMOYNE_CDP = "68714"
ROSWELL_VILLAGE = "68742"
RUDOLPH_CDP = "68938"
RUSHSYLVANIA_VILLAGE = "69176"
RUSHVILLE_VILLAGE = "69204"
RUSSELLS_POINT_VILLAGE = "69302"
RUSSELLVILLE_VILLAGE = "69316"
RUSSIA_VILLAGE = "69344"
RUTLAND_VILLAGE = "69358"
SABINA_VILLAGE = "69400"
SALEM_HEIGHTS_CDP_COLUMBIANA_COUNTY = "70044"
SALEM_HEIGHTS_CDP_HAMILTON_COUNTY = "70050"
SALEM_CITY = "69834"
SALESVILLE_CDP = "70072"
SALINEVILLE_VILLAGE = "70100"
SANDUSKY_CITY = "70380"
SANDYVILLE_CDP = "70464"
SARAHSVILLE_VILLAGE = "70520"
SARDINIA_VILLAGE = "70534"
SARDIS_CDP = "70548"
SAVANNAH_VILLAGE = "70576"
SAWYERWOOD_CDP = "70618"
SAYBROOK_ON_THE_LAKE_CDP = "70655"
SCIO_VILLAGE = "70814"
SCIOTODALE_CDP = "70912"
SCOTT_VILLAGE = "71080"
SEAMAN_VILLAGE = "71206"
SEBRING_VILLAGE = "71220"
SENECAVILLE_VILLAGE = "71360"
SEVEN_HILLS_CITY = "71416"
SEVEN_MILE_VILLAGE = "71444"
SEVILLE_VILLAGE = "71486"
SHADYSIDE_VILLAGE = "71640"
SHAKER_HEIGHTS_CITY = "71682"
SHARON_CENTER_CDP = "71836"
SHARONVILLE_CITY = "71892"
SHAWNEE_CDP = "71958"
SHAWNEE_HILLS_CDP = "71983"
SHAWNEE_HILLS_VILLAGE = "71976"
SHAWNEE_VILLAGE = "71962"
SHEFFIELD_LAKE_CITY = "72088"
SHEFFIELD_VILLAGE = "72060"
SHELBY_CITY = "72102"
SHERRODSVILLE_VILLAGE = "72242"
SHERWOOD_CDP = "72258"
SHERWOOD_VILLAGE = "72256"
SHILOH_CDP = "72284"
SHILOH_VILLAGE = "72298"
SHREVE_VILLAGE = "72396"
SIDNEY_CITY = "72424"
SILVER_LAKE_VILLAGE = "72494"
SILVERTON_VILLAGE = "72522"
SINKING_SPRING_VILLAGE = "72578"
SIXTEEN_MILE_STAND_CDP = "72620"
SKYLINE_ACRES_CDP = "72648"
SMITHVILLE_VILLAGE = "72788"
SOLON_CITY = "72928"
SOMERSET_VILLAGE = "72977"
SOMERVILLE_CDP = "72998"
SOUTH_AMHERST_VILLAGE = "73040"
SOUTH_BLOOMFIELD_VILLAGE = "73068"
SOUTH_CANAL_CDP = "73118"
SOUTH_CHARLESTON_VILLAGE = "73124"
SOUTH_EUCLID_CITY = "73264"
SOUTH_LEBANON_VILLAGE = "73446"
SOUTH_MOUNT_VERNON_CDP = "73530"
SOUTH_POINT_VILLAGE = "73670"
SOUTH_RUSSELL_VILLAGE = "73684"
SOUTH_SALEM_VILLAGE = "73698"
SOUTH_SOLON_VILLAGE = "73768"
SOUTH_VIENNA_VILLAGE = "73796"
SOUTH_WEBSTER_VILLAGE = "73824"
SOUTH_ZANESVILLE_VILLAGE = "73894"
SPARTA_VILLAGE = "73950"
SPENCER_VILLAGE = "73992"
SPENCERVILLE_VILLAGE = "74034"
SPRING_VALLEY_VILLAGE = "74216"
SPRINGBORO_CITY = "74076"
SPRINGDALE_CITY = "74104"
SPRINGFIELD_CITY = "74118"
ST_BERNARD_VILLAGE = "69470"
ST_CLAIRSVILLE_CITY = "69526"
ST_HENRY_VILLAGE = "69540"
ST_JOHNS_CDP = "69596"
ST_LOUISVILLE_VILLAGE = "69652"
ST_MARTIN_CDP = "69666"
ST_MARYS_CITY = "69680"
ST_PARIS_VILLAGE = "69708"
STAFFORD_VILLAGE = "74300"
STERLING_CDP = "74566"
STEUBENVILLE_CITY = "74608"
STEWART_CDP = "74622"
STOCKDALE_CDP = "74734"
STOCKPORT_VILLAGE = "74748"
STONE_CREEK_VILLAGE = "74804"
STONY_PRAIRIE_CDP = "74832"
STONY_RIDGE_CDP = "74846"
STOUTSVILLE_VILLAGE = "74916"
STOW_CITY = "74944"
STRASBURG_VILLAGE = "74958"
STRATTON_VILLAGE = "75000"
STREETSBORO_CITY = "75014"
STRONGSVILLE_CITY = "75098"
STRUTHERS_CITY = "75126"
STRYKER_VILLAGE = "75140"
SUFFIELD_CDP = "75182"
SUGAR_BUSH_KNOLLS_VILLAGE = "75196"
SUGAR_GROVE_VILLAGE = "75252"
SUGARCREEK_VILLAGE = "75210"
SULLIVAN_CDP = "75350"
SULPHUR_SPRINGS_CDP = "75392"
SUMMERFIELD_VILLAGE = "75406"
SUMMERSIDE_CDP = "75434"
SUMMITVILLE_VILLAGE = "75574"
SUNBURY_VILLAGE = "75602"
SWANTON_VILLAGE = "75896"
SYCAMORE_VILLAGE = "75980"
SYLVANIA_CITY = "76022"
SYRACUSE_VILLAGE = "76050"
TALLMADGE_CITY = "76106"
TARLTON_VILLAGE = "76148"
TAYLOR_CREEK_CDP = "76197"
TEDROW_CDP = "76358"
TERRACE_PARK_VILLAGE = "76428"
THE_PLAINS_CDP = "76568"
THE_VILLAGE_OF_INDIAN_HILL_CITY = "76582"
THORNPORT_CDP = "76666"
THORNVILLE_VILLAGE = "76680"
THURSTON_VILLAGE = "76764"
TIFFIN_CITY = "76778"
TILTONSVILLE_VILLAGE = "76806"
TIMBERLAKE_VILLAGE = "76834"
TIPP_CITY_CITY = "76876"
TIPPECANOE_CDP = "76890"
TIRO_VILLAGE = "76932"
TOLEDO_CITY = "77000"
TONTOGANY_VILLAGE = "77070"
TORONTO_CITY = "77112"
TREMONT_CITY_VILLAGE = "77308"
TRENTON_CITY = "77322"
TRIMBLE_VILLAGE = "77406"
TRINWAY_CDP = "77434"
TROTWOOD_CITY = "77504"
TROY_CITY = "77588"
TUPPERS_PLAINS_CDP = "77812"
TURPIN_HILLS_CDP = "77840"
TUSCARAWAS_VILLAGE = "77924"
TWINSBURG_HEIGHTS_CDP = "78078"
TWINSBURG_CITY = "78050"
UHRICHSVILLE_CITY = "78176"
UNION_CITY_VILLAGE = "78624"
UNION_CITY = "78470"
UNIONTOWN_CDP = "78736"
UNIONVILLE_CENTER_VILLAGE = "78834"
UNIOPOLIS_CDP = "78848"
UNIVERSITY_HEIGHTS_CITY = "78932"
UPPER_ARLINGTON_CITY = "79002"
UPPER_SANDUSKY_CITY = "79044"
URBANA_CITY = "79072"
URBANCREST_VILLAGE = "79100"
UTICA_VILLAGE = "79114"
VALLEY_CITY_CDP = "79184"
VALLEY_HI_VILLAGE = "79226"
VALLEY_VIEW_VILLAGE = "79268"
VALLEYVIEW_VILLAGE = "79282"
VAN_BUREN_VILLAGE = "79394"
VAN_WERT_CITY = "79562"
VANDALIA_CITY = "79492"
VANLUE_VILLAGE = "79534"
VAUGHNSVILLE_CDP = "79590"
VENEDOCIA_VILLAGE = "79632"
VERMILION_CITY = "79716"
VERONA_VILLAGE = "79898"
VERSAILLES_VILLAGE = "79912"
VICKERY_CDP = "79982"
VIENNA_CENTER_CDP = "80066"
VINCENT_CDP = "80150"
VINTON_VILLAGE = "80178"
WADSWORTH_CITY = "80304"
WAITE_HILL_VILLAGE = "80402"
WAKEMAN_VILLAGE = "80458"
WALBRIDGE_VILLAGE = "80486"
WALDO_VILLAGE = "80500"
WALNUT_CREEK_CDP = "80612"
WALTON_HILLS_VILLAGE = "80738"
WAPAKONETA_CITY = "80766"
WARREN_CITY = "80892"
WARRENSVILLE_HEIGHTS_CITY = "80990"
WARSAW_VILLAGE = "81032"
WASHINGTON_COURT_HOUSE_CITY = "81718"
WASHINGTONVILLE_VILLAGE = "81732"
WATERFORD_CDP = "81760"
WATERVILLE_CITY = "81858"
WAUSEON_CITY = "81928"
WAVERLY_VILLAGE = "81935"
WAYNE_LAKES_VILLAGE = "82348"
WAYNE_VILLAGE = "82334"
WAYNESBURG_VILLAGE = "82376"
WAYNESFIELD_VILLAGE = "82390"
WAYNESVILLE_VILLAGE = "82418"
WELLINGTON_VILLAGE = "82642"
WELLSTON_CITY = "82712"
WELLSVILLE_VILLAGE = "82740"
WEST_ALEXANDRIA_VILLAGE = "82880"
WEST_CARROLLTON_CITY = "83090"
WEST_ELKTON_VILLAGE = "83216"
WEST_FARMINGTON_VILLAGE = "83384"
WEST_HILL_CDP = "83541"
WEST_JEFFERSON_VILLAGE = "83580"
WEST_LAFAYETTE_VILLAGE = "83608"
WEST_LEIPSIC_VILLAGE = "83706"
WEST_LIBERTY_VILLAGE = "83734"
WEST_LOGAN_CDP = "83776"
WEST_MANCHESTER_VILLAGE = "83804"
WEST_MANSFIELD_VILLAGE = "83818"
WEST_MILLGROVE_VILLAGE = "83888"
WEST_MILTON_VILLAGE = "83902"
WEST_PORTSMOUTH_CDP = "84140"
WEST_RUSHVILLE_VILLAGE = "84182"
WEST_SALEM_VILLAGE = "84196"
WEST_UNION_VILLAGE = "84294"
WEST_UNITY_VILLAGE = "84308"
WESTERVILLE_CITY = "83342"
WESTFIELD_CENTER_VILLAGE = "83468"
WESTLAKE_CITY = "83622"
WESTMINSTER_CDP = "83930"
WESTON_VILLAGE = "83972"
WETHERINGTON_CDP = "84528"
WHARTON_VILLAGE = "84574"
WHEELERSBURG_CDP = "84588"
WHITE_OAK_CDP = "84812"
WHITEHALL_CITY = "84742"
WHITEHOUSE_VILLAGE = "84770"
WHITES_LANDING_CDP = "84882"
WICKLIFFE_CITY = "85036"
WIGHTMANS_GROVE_CDP = "85085"
WILBERFORCE_CDP = "85092"
WILKESVILLE_VILLAGE = "85190"
WILKSHIRE_HILLS_CDP = "85228"
WILLARD_CITY = "85232"
WILLIAMSBURG_VILLAGE = "85288"
WILLIAMSDALE_CDP = "85344"
WILLIAMSPORT_VILLAGE = "85414"
WILLISTON_CDP = "85442"
WILLOUGHBY_HILLS_CITY = "85512"
WILLOUGHBY_CITY = "85484"
WILLOWICK_CITY = "85638"
WILLSHIRE_VILLAGE = "85736"
WILMINGTON_CITY = "85792"
WILMOT_VILLAGE = "85806"
WILSON_VILLAGE = "85834"
WINCHESTER_VILLAGE = "85876"
WINDHAM_VILLAGE = "85946"
WINESBURG_CDP = "86072"
WINTERSVILLE_VILLAGE = "86184"
WITHAMSVILLE_CDP = "86254"
WOLFHURST_CDP = "86282"
WOODLAWN_VILLAGE = "86366"
WOODMERE_VILLAGE = "86394"
WOODSDALE_CDP = "86422"
WOODSFIELD_VILLAGE = "86436"
WOODSTOCK_VILLAGE = "86478"
WOODVILLE_VILLAGE = "86492"
WOODWORTH_CDP = "86534"
WOOSTER_CITY = "86548"
WORTHINGTON_CITY = "86604"
WREN_VILLAGE = "86632"
WRIGHT_PATTERSON_AFB_CDP = "86660"
WYOMING_CITY = "86730"
XENIA_CITY = "86772"
YANKEE_LAKE_VILLAGE = "86856"
YELLOW_SPRINGS_VILLAGE = "86940"
YORKSHIRE_VILLAGE = "87164"
YORKVILLE_VILLAGE = "87178"
YOUNGSTOWN_CITY = "88000"
ZALESKI_VILLAGE = "88028"
ZANESFIELD_VILLAGE = "88070"
ZANESVILLE_CITY = "88084"
ZOAR_VILLAGE = "88168"
